==> certmanager-model-v1beta1-6.4.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeFluentImpl<A extends ACMEChallengeFluent<A>> extends BaseFluent<A> implements ACMEChallengeFluent<A>{
  public ACMEChallengeFluentImpl() {
  }
  public ACMEChallengeFluentImpl(ACMEChallenge instance) {
    this.withToken(instance.getToken()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
  }
  private String token;
  private String type;
  private String url;
  public String getToken() {
    return this.token;
  }
  public A withToken(String token) {
    this.token=token; return (A) this;
  }
  public Boolean hasToken() {
    return this.token != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeFluentImpl that = (ACMEChallengeFluentImpl) o;
    if (token != null ? !token.equals(that.token) :that.token != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(token,  type,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (token != null) { sb.append("token:"); sb.append(token + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1beta1-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeFluentImpl<A extends ACMEChallengeFluent<A>> extends BaseFluent<A> implements ACMEChallengeFluent<A>{
  public ACMEChallengeFluentImpl() {
  }
  public ACMEChallengeFluentImpl(ACMEChallenge instance) {
    if (instance != null) {
      this.withToken(instance.getToken());
      this.withType(instance.getType());
      this.withUrl(instance.getUrl());
    }
  }
  private String token;
  private String type;
  private String url;
  public String getToken() {
    return this.token;
  }
  public A withToken(String token) {
    this.token=token; return (A) this;
  }
  public Boolean hasToken() {
    return this.token != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeFluentImpl that = (ACMEChallengeFluentImpl) o;
    if (!java.util.Objects.equals(token, that.token)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(token,  type,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (token != null) { sb.append("token:"); sb.append(token + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}
